/*
 * Copyright (C) 2011  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 */

package org.ow2.orchestra.login.client.ui.impl;

import com.google.gwt.core.client.GWT;
import com.google.gwt.resources.client.ImageResource;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiFactory;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.uibinder.client.UiTemplate;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.FormPanel;
import com.google.gwt.user.client.ui.Image;
import com.google.gwt.user.client.ui.Label;
import com.google.gwt.user.client.ui.PasswordTextBox;
import com.google.gwt.user.client.ui.TextBox;
import com.google.gwt.user.client.ui.Widget;
import org.ow2.orchestra.login.client.ImageButton;
import org.ow2.orchestra.login.client.ui.LoginView;

/**
 * @author Loic Albertin
 */
public class LoginViewImplAccess extends Composite implements LoginView {

  public interface Resources extends LoginView.Resources {
    @Source("login.gif")
    ImageResource loginButton();

    @Source("error_button.png")
    ImageResource errorButton();

    @Source({LoginView.Style.DEFAULT_CSS, LoginViewImplAccess.Style.DEFAULT_CSS})
    LoginViewImplAccess.Style style();
  }

  public interface Style extends LoginView.Style {
    static final String DEFAULT_CSS = "org/ow2/orchestra/login/client/ui/impl/access.css";

    String loginForm();

    String formCaption();

    String loginPanel();

    String errorImg();

    String loginFailedLabel();

    String internalPanel();

    String loginLabel();
  }

  @UiField(provided = true)
  final LoginViewImplAccess.Resources resources = GWT.create(LoginViewImplAccess.Resources.class);

  @UiTemplate("LoginViewImplAccess.ui.xml")
  interface LoginViewImplAccessUiBinder extends UiBinder<Widget, LoginViewImplAccess> {
  }

  private static LoginViewImplAccessUiBinder uiBinder = GWT.create(LoginViewImplAccessUiBinder.class);

  @UiField
  FormPanel formPanel;
  @UiField
  Image loginFailedButton;
  @UiField
  Label loginFailedLabel;
  @UiField
  TextBox userNameTextBox;
  @UiField
  PasswordTextBox passwordTextBox;
  @UiField
  ImageButton submitButton;

  public LoginViewImplAccess() {
    resources.style().ensureInjected();
    initWidget(LoginViewImplAccess.uiBinder.createAndBindUi(this));

    if (Window.Location.getHref().contains("j_security_check")) {
      loginFailedLabel.setVisible(true);
      loginFailedButton.setVisible(true);

    } else {
      loginFailedLabel.setVisible(false);
      loginFailedButton.setVisible(false);
    }

  }

  @UiFactory
  FormPanel constructor() {
    return new FormPanel("_self");
  }

}
