/*
 * Copyright (C) 2011  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 */

package org.ow2.orchestra.login.client.ui.impl;

import com.google.gwt.core.client.GWT;
import com.google.gwt.dom.client.FrameElement;
import com.google.gwt.event.dom.client.LoadEvent;
import com.google.gwt.event.dom.client.LoadHandler;
import com.google.gwt.i18n.client.DateTimeFormat;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.Frame;
import org.ow2.orchestra.login.client.LoginService;
import org.ow2.orchestra.login.client.LoginServiceAsync;

import java.util.Date;

/**
 * @author Loic Albertin
 */
public class PresenterImpl implements LoginViewImplShell.Presenter {

  private final LoginServiceAsync loginService = GWT.create(LoginService.class);

  private LoginViewImplShell loginViewImplShell;

  public PresenterImpl(LoginViewImplShell loginViewImplShell) {
    this.loginViewImplShell = loginViewImplShell;
  }

  public void getUserName() {
    loginService.getSessionUserName(new AsyncCallback<String>() {

      public void onFailure(Throwable caught) {
        GWT.log("Could not retrieve user name", caught);
        PresenterImpl.this.loginViewImplShell.setUserName("unknown");
      }

      public void onSuccess(String result) {
        PresenterImpl.this.loginViewImplShell.setUserName(result);
      }
    });
  }

  public void getConnectionTime() {
    loginService.getSessionCreationDate(new AsyncCallback<Long>() {
      public void onFailure(Throwable caught) {
        GWT.log("Could not retrieve session creation date", caught);
        PresenterImpl.this.loginViewImplShell.setConnectionTime("unknown");
      }

      public void onSuccess(Long result) {
        Date date = new Date(result);
        DateTimeFormat processDateFormat = DateTimeFormat.getFormat("dd/MM/yyyy 'at' HH:mm:ss");
        PresenterImpl.this.loginViewImplShell.setConnectionTime(processDateFormat.format(date));
      }
    });
  }

  public void logout() {
    loginService.sessionLogout(new AsyncCallback<Void>() {

      public void onSuccess(Void result) {
        Window.Location.reload();
      }

      public void onFailure(Throwable caught) {
        GWT.log("logout fail !", caught);
      }
    });
  }

  public Frame getMainFrame() {
    final Frame frame = new Frame(GWT.getHostPageBaseURL()+"index2.html");
    frame.setWidth("100%");
    frame.setHeight("100%");
    frame.setStyleName("frameStyle");
    frame.ensureDebugId("contentFrame");

    frame.addDomHandler(new LoadHandler() {
      public void onLoad(LoadEvent event) {
        Window.setTitle(frame.getElement().<FrameElement>cast().getContentDocument().getTitle());
      }
    }, LoadEvent.getType());
    return frame;
  }
}
